showDeleteAllIcon property
Whether to show the delete all icon (clear/X button). When true, displays a clear button that clears the current selection. Defaults to true.
Implementation
final bool showDeleteAllIcon;
Whether to show the delete all icon (clear/X button). When true, displays a clear button that clears the current selection. Defaults to true.
final bool showDeleteAllIcon;