showDropdownPositionIcon property
Whether to show the dropdown position icon (arrow up/down). When true, displays an arrow icon that toggles the dropdown visibility. Defaults to true.
Implementation
final bool showDropdownPositionIcon;
Whether to show the dropdown position icon (arrow up/down). When true, displays an arrow icon that toggles the dropdown visibility. Defaults to true.
final bool showDropdownPositionIcon;