ItemDropperItem<T> class
Generic dropdown item with value and display label
Constructors
- ItemDropperItem({required T value, required String label, bool isGroupHeader = false, bool isDeletable = false, bool isEnabled = true})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDeletable → bool
-
final
- isEnabled → bool
-
Whether this item is enabled (selectable) in the dropdown.
Disabled items are rendered but cannot be selected.
final
- isGroupHeader → bool
-
Whether this item is a group header (non-selectable label).
Group headers are displayed but cannot be selected.
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited